# kt-legacy

This repository is to support the deprecated import name of Keras Tuner.
With this repo, you can import Keras Tuner as `kerastuner`.
In the main Keras Tuner repository the import name has been changed to `keras_tuner`.
